# -*- coding: ISO-8859-1 -*-

##############################################################################
#
# Copyright (c) 2006 Alexis Roda. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
##############################################################################

"""

$Id: zipfolder.py 16 2006-05-21 22:42:28Z alex $
"""

__version__ = "$Revision: $"
# $Source: $

import md5

from AccessControl import ClassSecurityInfo
from AccessControl import Permissions as ZopePerms
from Acquisition import aq_base
from Globals import InitializeClass
from Globals import DTMLFile
from OFS.Folder import Folder
from Persistence import PersistentMapping
from zExceptions import BadRequest


_marker = []

class ZipFolder(Folder) :
    """
    """
    security = ClassSecurityInfo()
    meta_type = 'ziptool:zipfolder'

    manage_options = (
        Folder.manage_options[:2] +
        ({'label':'NameMap', 'action':'manage_nameMap'},) +
        Folder.manage_options[2:]
        )

    manage_nameMap = DTMLFile('dtml/manage_nameMap', globals())

    def __init__(self, id) :
        Folder.__init__(self, id)
        self._name_map = PersistentMapping()
        self._rev_name_map = PersistentMapping()

    security.declareProtected(ZopePerms.access_contents_information,
                              'getNameMap')
    def getNameMap(self) :
        return dict(self._name_map)

    def _checkId(self, id, allow_dup=0):
        try:
            new_id = Folder._checkId(self, id, allow_dup)
        except BadRequest:
            new_id = md5.new(id).hexdigest()
            self._name_map[id] = new_id
            self._rev_name_map[new_id] = id
        return new_id

    def _delOb(self, id):
        old_id = self._rev_name_map.get(id)
        if old_id is not None :
            del self._name_map[old_id]
            del self._rev_name_map[id]
        delattr(self, id)

    def _getOb(self, id, default=_marker):
        if id[:1] != '_' and hasattr(aq_base(self), id):
            return getattr(self, id)
        id2 = self._name_map.get(id, None)
        if id2 is not None :
            if id2[:1] != '_' and hasattr(aq_base(self), id2):
                return getattr(self, id2)
        if default is _marker:
            raise AttributeError(id)
        return default


InitializeClass(ZipFolder)


def manage_addZipFolder(self, id, REQUEST=None) :
    """'
    """
    zt = ZipFolder(id)
    self._setObject(id, zt)
    if REQUEST is not None :
        REQUEST.RESPONSE.redirect('./manage_main')
